aboutsummaryrefslogtreecommitdiff
path: root/libjava/resolve.cc
diff options
context:
space:
mode:
Diffstat (limited to 'libjava/resolve.cc')
-rw-r--r--libjava/resolve.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/libjava/resolve.cc b/libjava/resolve.cc
index ea0faad..2b25b57 100644
--- a/libjava/resolve.cc
+++ b/libjava/resolve.cc
@@ -958,9 +958,9 @@ get_ffi_type_from_signature (unsigned char* ptr)
* function is non-static, then one is added to the number of elements
* found in the signature */
-static int
-count_arguments (_Jv_Utf8Const *signature,
- jboolean staticp)
+int
+_Jv_count_arguments (_Jv_Utf8Const *signature,
+ jboolean staticp)
{
unsigned char *ptr = (unsigned char*) signature->data;
int arg_count = staticp ? 0 : 1;
@@ -1048,7 +1048,7 @@ init_cif (_Jv_Utf8Const* signature,
#endif
/* we put this one here, and not in interpret.cc because it
* calls the utility routines count_arguments
* which are static to this module. The following struct defines the
* layout we use for the stubs, it's only used in the ncode method. */
@@ -1069,7 +1069,7 @@ _Jv_InterpMethod::ncode ()
return self->ncode;
jboolean staticp = (self->accflags & Modifier::STATIC) != 0;
- int arg_count = count_arguments (self->signature, staticp);
+ int arg_count = _Jv_count_arguments (self->signature, staticp);
ncode_closure *closure =
(ncode_closure*)_Jv_AllocBytes (sizeof (ncode_closure)
@@ -1119,7 +1119,7 @@ _Jv_JNIMethod::ncode ()
return self->ncode;
jboolean staticp = (self->accflags & Modifier::STATIC) != 0;
- int arg_count = count_arguments (self->signature, staticp);
+ int arg_count = _Jv_count_arguments (self->signature, staticp);
ncode_closure *closure =
(ncode_closure*)_Jv_AllocBytes (sizeof (ncode_closure)
@@ -1180,7 +1180,7 @@ _Jv_BuildResolvedMethod (_Jv_Method* method,
jboolean staticp,
jint vtable_index)
{
- int arg_count = count_arguments (method->signature, staticp);
+ int arg_count = _Jv_count_arguments (method->signature, staticp);
_Jv_ResolvedMethod* result = (_Jv_ResolvedMethod*)
_Jv_AllocBytes (sizeof (_Jv_ResolvedMethod)
@@ -1048,7 +1048,7 @@ init_cif (_Jv_Utf8Const* signature,
#endif
/* we put this one here, and not in interpret.cc because it
- * calls the utility routines count_arguments
+ * calls the utility routines _Jv_count_arguments
* which are static to this module. The following struct defines the
* layout we use for the stubs, it's only used in the ncode method. */